/*
 * Notification-related functions and types.
 *
 * Copyright (C) 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <systypes/base.h>



/* C compatibility types (defined in the implementation). */

struct notifier;

typedef struct notifier notifier_t;



EXTERN_C_BEGIN

notifiable_t *notify_notifiable(notifiable_base_t *notifiable);
notify_flags_t notify_notifications(notifiable_base_t *notifiable);
notify_values_t notify_notification_values(notifiable_base_t *notifiable);

void notify_close(notifier_t *notifier);

notifier_t *notify_get_local(void);
notifier_t *notify_get_task(void);

long notify_subscribe(notifiable_t *notifiable, notify_flags_t flags, notifier_t *notifier);
long notify_unsubscribe(notifiable_t *notifiable, notifier_t *notifier);

long notify_wait(notifiable_t *notifiable, notifier_t *notifier);
long notify_wait_many(notifiable_t **notifiable, notifier_t *notifier);

EXTERN_C_END

// vim: tabstop=2 expandtab shiftwidth=2
